%% FACS data analysis: scatter plots and histograms for YFP expression in liposomes.
% This program analyses FACS data for creating scatter plots and
% histograms.
% Steps for importing data:
    % Take the .fcs data from FACS instrument.
    % Import .fcs data into https://community.cytobank.org/
    % Filter the data accordingly (NO debris TX-red + NO debris dsGreen/YFP)
    % Export the filtered .fcs data as .txt files from https://community.cytobank.org/
        % Go to actions/export/export events/.txt file format/chose filter population to export/chose files to export/leave the channels as it is (all channels will be exported 
    % Save the .txt data in the same folder as this script is (the folder should also have importfile.m)

% For figures:
table{1}= importfile('Specimen_001_B1_B01_001.fcs_water.txt'); 
table{2}= importfile('Specimen_001_B2_B02_002.PSSA only.txt'); 
table{3}= importfile('Specimen_001_B3_B03_003.expCADGE +dNTPs.txt'); 
table{4}= importfile('Specimen_001_B4_B04_004.expCADGE -dNTPs.txt'); 
table{5}= importfile('Specimen_001_B5_B05_005.purCADGE +dNTPs.txt'); 
table{6}= importfile('Specimen_001_B6_B06_006.purCADGE -dNTPs.txt'); 

samples = ["water", "PSSA only", "expCADGE +dNTPs", "expCADGE -dNTPs", "purCADGE +dNTPs", "purCADGE -dNTPs"]

set(groot,{'DefaultAxesXColor','DefaultAxesYColor','DefaultAxesZColor','DefaultAxesLineWidth'},{'k','k','k',1})
x = 1:100:10000000;
y = (x).^2;

% defining the water threshold
%treshold=mean((table{6}.AlexaFluor488A)+(6*std(table{6}.AlexaFluor488A)))

YFP2=[];

for c = 1:6;
    YFP = [] %Expressed population (change the table{#} depending on the population to analyze)
for i = 1:length(table{c}.PETexasRedA)
    if table{c}.PETexasRedA(i) > 26*(table{c}.SSCA(i).^0.9)
        %&& table{1}.PETexasRedA(i) < mean((table{2}.PETexasRedA)+(2*std(table{2}.PETexasRedA)))
        YFP = [YFP; table{c}.PETexasRedA(i)];
    end
end

Per_YFP = (length(YFP)/length(table{c}.PETexasRedA))*100; %percentage of YFP expressing liposomes.
Per_YFP = round(Per_YFP,2) %round the percentage to only 2 decimals 
str = '' + string(Per_YFP) + {'%'} %conver to string for it to appear in the scatter plot.

%Scatter plots from FACS
f(c) = figure;
box on
set(gca,'FontSize',14);
h = get(gca, 'title');
set(h, 'FontSize',14)

scatter(table{c}.SSCA, table{c}.PETexasRedA,7,'filled','MarkerFaceColor','#77AC30')
hold on 
plot(1:10^6,26*(1:10^6).^0.9,'--k','LineWidth',1.5);
% yline(treshold,'--k','LineWidth',2,'label',str,'fontsize',12)
set(gca,'xscale','log')
set(gca,'yscale','log')

xlim([10 10^4])
ylim([10^0 10^6])
legend(samples(c),'background treshold','Location','NW','FontSize',12)
legend boxoff
xlabel('Membrane dye intensity (A.U)')
ylabel('YFP intensity (A.U)')
set(gca,'FontSize',14);
h = get(gca, 'title');
set(h, 'FontSize',14)
print(f(c),'-dpng','-r1000','PF1 flow cytometry')

YFP_cell{c}=YFP;
Per_YFP_cell{c}=Per_YFP

end

% f3 = figure; 
% histogram(YFP_cell{1},'BinWidth',100,'facecolor','#FF0000','FaceAlpha',0.1,'EdgeAlpha',1,'Normalization','count');
% hold on
% histogram(YFP_cell{3},'BinWidth',100,'facecolor','#0000FF','FaceAlpha',0.1,'EdgeAlpha',1,'Normalization','count');
% histogram(YFP_cell{5},'BinWidth',100,'facecolor','#00FFFF','FaceAlpha',0.1,'EdgeAlpha',1,'Normalization','count');
% xline(mean((table{6}.AlexaFluor488A)+(4*std(table{6}.AlexaFluor488A))),'--k','LineWidth',2,'fontsize',20)
% set(gca,'yscale','log')
% xlim([-500 11e3])
% legend('oriYFP "all expresed','oriYFP "all purified"','oriYFP only','Water Background Treshold','Location','NE','FontSize',12)
% legend boxoff
% xlabel('YFP intensity ','FontSize',14);
% ylabel('Log(count)','FontSize',14);
% set(gca,'fontsize',14)
% print(f3,'-dpng','-r1000','PF3 Histogram')
