function h = scatter_kde(x, y, varargin)
% Scatter plot where each point is colored by the spatial density of nearby
% points. The function use the kernel smoothing function to compute the
% probability density estimate (PDE) for each point. It uses the PDE has
% color for each point.
%
% Input
%     x <Nx1 double> position of markers on X axis
%     y <Nx1 double> posiiton of markers on Y axis
%     varargin can be used to send a set of instructions to the scatter function
%           Supports the MarkerSize parameter
%           Does not support the MarkerColor parameter
%
% Output:
%     h returns handles to the scatter objects created
%
% Example
%     % Generate data
%     x = normrnd(10,1,1000,1);
%     y = x*3 + normrnd(10,1,1000,1);
%     % Plot data using probability density estimate as function
%     figure(1); 
%     scatter_kde(x, y, 'filled', 'MarkerSize', 100);
%     % Add Color bar
%     cb = colorbar();
%     cb.Label.String = 'Probability density estimate';
%
% author: Nils Haentjens
% created: Jan 15, 2018

table{1}= importfile('Specimen_001_B1_B01_001.fcs_water.txt'); 
table{2}= importfile('Specimen_001_B2_B02_002.PSSA only.txt'); 
table{3}= importfile('Specimen_001_B3_B03_003.expCADGE +dNTPs.txt'); 
table{4}= importfile('Specimen_001_B4_B04_004.expCADGE -dNTPs.txt'); 
table{5}= importfile('Specimen_001_B5_B05_005.purCADGE +dNTPs.txt'); 
table{6}= importfile('Specimen_001_B6_B06_006.purCADGE -dNTPs.txt'); 

samples = ["water", "PSSA only", "expCADGE +dNTPs", "expCADGE -dNTPs", "purCADGE +dNTPs", "purCADGE -dNTPs"]

% Use Kernel smoothing function to get the probability density estimate (c)
c = ksdensity([table{1}.SSCA,table{1}.PETexasRedA], [table{1}.SSCA,table{1}.PETexasRedA]);

if nargin > 2
  % Set Marker Size
  i = find(strcmp(varargin, 'MarkerSize'),1);
  if ~isempty(i); MarkerSize = varargin{i+1}; varargin(i:i+1) = [];
  else MarkerSize = []; end
  % Plot scatter plot
  h = scatter(x, y, MarkerSize, c, varargin{:});
else
  h = scatter(x, y, [], c);
end

end